@@ -1,5 +1,5 @@
 from ._metakernel import (
-    MetaKernel, IPythonKernel, register_ipython_magics, get_metakernel)
+    ExceptionWrapper, MetaKernel, IPythonKernel, register_ipython_magics, get_metakernel)
 from . import pexpect
 from .replwrap import REPLWrapper, u
 from .process_metakernel import ProcessMetaKernel
@@ -8,6 +8,6 @@ from .parser import Parser
 
 __all__ = ['Magic', 'MetaKernel', 'option']
 
-__version__ = '0.16.3'
+__version__ = '0.17.0'
 
 del magic, _metakernel, parser, process_metakernel
